%define major      1
%define libname    %mklibname %{name} %{major}
%define devname    %mklibname %{name} -d
%define staticname %mklibname %{name} -d -s

# Glslang revision from packaged version
%define glslang_version 11.12.0

Name:           shaderc
Version:        2022.3
Release:        %mkrel 1
Summary:        A collection of tools, libraries, and tests for Vulkan shader compilation
Group:          System/Libraries
License:        ASL 2.0
URL:            https://github.com/google/shaderc
Source0:        https://github.com/google/shaderc/archive/v%{version}/%{name}-%{version}.tar.xz
# Patches to unbundle 3rd party code
Patch1:         shaderc-2022.1-cmakelists.patch
Patch2:         shaderc-2020.4-system-glslang.patch

BuildRequires:  cmake
BuildRequires:  glslang-devel = %{glslang_version}
BuildRequires:  pkgconfig(SPIRV-Tools)
BuildRequires:  python3
BuildRequires:  spirv-headers
BuildRequires:  spirv-tools

%description
A collection of tools, libraries and tests for shader compilation.

Shaderc aims to to provide:
 - a command line compiler with GCC- and Clang-like usage, for better
   integration with build systems
 - an API where functionality can be added without breaking existing clients
 - an API supporting standard concurrency patterns across multiple
   operating systems
 - increased functionality such as file #include support

%package -n glslc
Summary:        A command line compiler for GLSL/HLSL to SPIR-V
Group:          Development/Tools

%description -n glslc
A command line compiler for GLSL/HLSL to SPIR-V.

%package -n %{libname}
Summary:        A library for compiling shader strings into SPIR-V
Group:          System/Libraries

%description -n %{libname}
A library for compiling shader strings into SPIR-V.

%package -n %{devname}
Summary:        Development files for libshaderc
Group:          Development/Libraries
Requires:       %{libname} = %{version}-%{release}

%description -n %{devname}
A library for compiling shader strings into SPIR-V.
Development files for libshaderc.

%package -n %{staticname}
Summary:        A library for compiling shader strings into SPIR-V (static libraries)
Group:          Development/Libraries

%description -n %{staticname}
A library for compiling shader strings into SPIR-V.
Static libraries for libshaderc.

%prep
%autosetup -p1 -n %{name}-%{version}

rm -rf third_party

# Stolen from Gentoo
# Create build-version.inc since we want to use our packaged
# SPIRV-Tools and glslang
echo \"shaderc $(grep -m1 -o '^v[[:digit:]]\{4\}\.[[:digit:]]\(-dev\)\? [[:digit:]]\{4\}-[[:digit:]]\{2\}-[[:digit:]]\{2\}$' CHANGES)\" \
        > glslc/src/build-version.inc
echo \"spirv-tools $(grep -m1 -o '^v[[:digit:]]\{4\}\.[[:digit:]]\(-dev\)\? [[:digit:]]\{4\}-[[:digit:]]\{2\}-[[:digit:]]\{2\}$' /usr/share/doc/spirv-tools/CHANGES)\" \
        >> glslc/src/build-version.inc
echo \"glslang %{glslang_version}\" >> glslc/src/build-version.inc

# Point to correct include
sed -i 's|SPIRV/GlslangToSpv.h|glslang/SPIRV/GlslangToSpv.h|' libshaderc_util/src/compiler.cc

%build
# We disable the tests because they don't work with our unbundling of 3rd party.
# See https://github.com/google/shaderc/issues/470
%cmake \
  -DSHADERC_SKIP_EXAMPLES=ON \
  -DSHADERC_SKIP_TESTS=ON \
  -DSHADERC_ENABLE_WERROR_COMPILE=OFF
%cmake_build

%install
%cmake_install

%files -n glslc
%{_bindir}/glslc

%files -n %{libname}
%{_libdir}/lib%{name}_shared.so.%{major}{,.*}

%files -n %{devname}
%{_includedir}/%{name}/
%{_libdir}/lib%{name}_shared.so
%{_libdir}/pkgconfig/%{name}.pc

%files -n %{staticname}
%{_libdir}/lib%{name}.a
%{_libdir}/lib%{name}_combined.a
%{_libdir}/pkgconfig/%{name}_static.pc
%{_libdir}/pkgconfig/%{name}_combined.pc


%changelog
* Fri Dec 01 2023 tex - 2022.3-1pclos2023
- create pkg
